Simpilfies vailidating user input and return True/False based on a list of expected inputs.
List of possible entries and return values:
True:..........False:

y..............n
yes............no
true...........0
yep............nope
allright.......false
alright........not
verywell.......noindeed
ofcourse.......absolutelynot
byallmeans.....mostcertainlynot
sure...........ofcoursenot
certainly......undernocircumstances
absolutely.....bynomeans
indeed.........notatall
affirmative....negative
agreed.........never
roger..........notreally
aye............nothanks
ayeaye.........nae
yeah...........nope
yah............nah
yep............notonyourlife
yup............noway
uh-huh.........nofear
okay...........notonyournelly
ok.............nosiree
okey-dokey.....naw
okey-doke
achcha
righto
righty-ho
surely
